@@ -2,7 +2,7 @@ pub mod identify;
 pub mod reaction_remove_emoji;
 pub mod request_guild_members;
 pub mod resume;
-pub mod update_status;
+pub mod update_presence;
 
 mod ban_add;
 mod ban_remove;
@@ -19,6 +19,7 @@ mod heartbeat;
 mod integration_create;
 mod integration_delete;
 mod integration_update;
+mod interaction_create;
 mod invite_create;
 mod invite_delete;
 mod member_add;
@@ -55,17 +56,18 @@ pub use self::{
     guild_emojis_update::GuildEmojisUpdate, guild_integrations_update::GuildIntegrationsUpdate,
     guild_update::GuildUpdate, heartbeat::Heartbeat, integration_create::IntegrationCreate,
     integration_delete::IntegrationDelete, integration_update::IntegrationUpdate,
-    invite_create::InviteCreate, invite_delete::InviteDelete, member_add::MemberAdd,
-    member_chunk::MemberChunk, member_remove::MemberRemove, member_update::MemberUpdate,
-    message_create::MessageCreate, message_delete::MessageDelete,
-    message_delete_bulk::MessageDeleteBulk, message_update::MessageUpdate,
-    presence_update::PresenceUpdate, reaction_add::ReactionAdd, reaction_remove::ReactionRemove,
-    reaction_remove_all::ReactionRemoveAll, reaction_remove_emoji::ReactionRemoveEmoji,
-    ready::Ready, request_guild_members::RequestGuildMembers, role_create::RoleCreate,
-    role_delete::RoleDelete, role_update::RoleUpdate, stage_instance_create::StageInstanceCreate,
+    interaction_create::InteractionCreate, invite_create::InviteCreate,
+    invite_delete::InviteDelete, member_add::MemberAdd, member_chunk::MemberChunk,
+    member_remove::MemberRemove, member_update::MemberUpdate, message_create::MessageCreate,
+    message_delete::MessageDelete, message_delete_bulk::MessageDeleteBulk,
+    message_update::MessageUpdate, presence_update::PresenceUpdate, reaction_add::ReactionAdd,
+    reaction_remove::ReactionRemove, reaction_remove_all::ReactionRemoveAll,
+    reaction_remove_emoji::ReactionRemoveEmoji, ready::Ready,
+    request_guild_members::RequestGuildMembers, role_create::RoleCreate, role_delete::RoleDelete,
+    role_update::RoleUpdate, stage_instance_create::StageInstanceCreate,
     stage_instance_delete::StageInstanceDelete, stage_instance_update::StageInstanceUpdate,
-    typing_start::TypingStart, unavailable_guild::UnavailableGuild, update_status::UpdateStatus,
-    update_voice_state::UpdateVoiceState, user_update::UserUpdate,
+    typing_start::TypingStart, unavailable_guild::UnavailableGuild,
+    update_presence::UpdatePresence, update_voice_state::UpdateVoiceState, user_update::UserUpdate,
     voice_server_update::VoiceServerUpdate, voice_state_update::VoiceStateUpdate,
     webhooks_update::WebhooksUpdate,
 };
